parameters consNum;

set option public.Global_database_id = {consNum};
set option public.delete_old_logs = 'ON';

create table Admin (
  admin_id      bigint default global autoincrement(1000000) primary key,
  data          varchar(30),
  last_modified timestamp default timestamp
);

call ml_add_column( 'v1', 'Admin', 'admin_id', NULL );
call ml_add_column( 'v1', 'Admin', 'data', NULL );
call ml_add_column( 'v1', 'Admin', 'cons', NULL );

create table Admin_del (
  pk bigint default autoincrement primary key,
  admin_id bigint,
  del_time timestamp default current timestamp
);

create trigger bd_admin before delete on admin
referencing old as pr for each row
begin
  insert into Admin_del(admin_id) values (pr.admin_id);
end;

call ml_add_table_script( 'v1', 'Admin', 'upload_insert', 
'insert into Admin(admin_id,data) values ({ml r.admin_id},{ml r.data})'
);

call ml_add_table_script( 'v1', 'Admin', 'upload_update',
'update Admin set data = {ml r.data} where admin_id = {ml r.admin_id}'
);

call ml_add_table_script( 'v1', 'Admin', 'upload_delete',
'delete from Admin where admin_id = {ml r.admin_id}'
);

call ml_add_table_script( 'v1', 'Admin', 'download_cursor',
'select admin_id, data, {consNum} from Admin 
 where last_modified >= {ml s.last_table_download}'
);

call ml_add_table_script( 'v1', 'Admin', 'download_delete_cursor',
'select admin_id from Admin_del where del_time >= {ml s.last_table_download}'
);

create procedure ULHandleError( out action        integer,
                                in  error_code    integer,
                                in  error_message varchar(1000),
                                in  user_name     varchar(128),
                                in  table_name    varchar(128) )
begin
  if error_code = -196 or error_code = -194 then
    set action = 1000;
  else
    set action = 3000;
  end if;
end;

call ml_add_connection_script( 'v1', 'handle_error', 
'CALL ULHandleError( {ml s.action_code}, {ml s.Error_code}, 
                     {ml s.error_message}, {ml s.username}, {ml s.table} )' 
);

create procedure rep_data
   ( in iter integer default 1, 
     in do_commit integer default 0 ) 
begin
  declare j integer;
  
  set j = 0;
  while j < iter loop
    insert into admin(data) values (cast(rand()*20 + 1 as char(10)));
    set j = j + 1;
    if do_commit = 1 then
      commit;
    end if;
  end loop;
  commit;
end;

call rep_data( 5 );
